﻿/**
 * Copyright (c) 2013 Tobias Müller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using System;
using System.Collections.Generic;
using UnityEngine;

/*
 * A color mapper, mapping flexible colors (see FlexibleColor) to unity colors.
 * The GameManager contains an instance of this which can be modified in the Unity editor.
 */
[Serializable]
class FlexibleColorAssignment
{
    [SerializeField] private Color a = Color.red;
    [SerializeField] private Color b = Color.blue;
    [SerializeField] private Color c = Color.yellow;
    [SerializeField] private Color ab = Color.magenta;
    [SerializeField] private Color ac = new Color(1, 0.5f, 0); // Orange
    [SerializeField] private Color bc = Color.green;
    [SerializeField] private Color abc = Color.white;

    private Dictionary<FlexibleColor, Color> colorMap;

    private void InitializeMap()
    {
        colorMap = new Dictionary<FlexibleColor, Color>();
        colorMap[FlexibleColor.A] = a;
        colorMap[FlexibleColor.B] = b;
        colorMap[FlexibleColor.C] = c;
        colorMap[FlexibleColor.A | FlexibleColor.B] = ab;
        colorMap[FlexibleColor.A | FlexibleColor.C] = ac;
        colorMap[FlexibleColor.B | FlexibleColor.C] = bc;
        colorMap[FlexibleColor.A | FlexibleColor.B | FlexibleColor.C] = abc;
    }

    public Color GetColor(FlexibleColor flexibleColor)
    {
        // Initialize the color map on first request
        if (colorMap == null)
            InitializeMap();

        if (!colorMap.ContainsKey(flexibleColor))
            throw new Exception("Unknown color: " + flexibleColor);

        return colorMap[flexibleColor];
    }
}
