/**
 * Copyright (c) 2013 Tobias Mller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using System;
using UnityEngine;
using System.Collections;

/*
 * An ingame entity to be shown on the PlayField. Each IngameEntity can be hit by a laser;
 * this class is the first to decide what happens then - block it, ignore it (let it pass through)
 * or pass the decision on to another part of the GameObject (for example a MirrorEntity).
 */
public class Entity : LaserReceiverMonoBehaviour
{
    public enum ReceiverBehaviour
    {
        BlockLaser,
        IgnoreLaser,
        UseLinkedReceiverBehaviour
    }

    [SerializeField] private ReceiverBehaviour receiverBehaviour;
    [SerializeField] private LaserReceiverMonoBehaviour linkedReceiverBehaviour;

    public override bool LaserHit(LaserThread laserThread, RaycastHit hit)
    {
        switch (receiverBehaviour)
        {
            case ReceiverBehaviour.IgnoreLaser:
                return false;

            case ReceiverBehaviour.BlockLaser:
                laserThread.AddPosition(hit.point, Vector3.zero);
                return true;

            case ReceiverBehaviour.UseLinkedReceiverBehaviour:
                return linkedReceiverBehaviour.LaserHit(laserThread, hit);

            default:
                throw new Exception("Receiver Behaviour not implemented: " + receiverBehaviour);
        }
    }
}
