﻿/**
 * Copyright (c) 2013 Tobias Müller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using UnityEngine;

/*
 * Any object that can receive a laser thread should be a child of this abstract class.
 * 
 * This should actually be an interface, but Unity can't have interfaces as property in the editor.
 * Since every LaserReceiver is also an MonoBehaviour by nature, it doesn't hurt that it's an abstract
 * class now.
 */
public abstract class LaserReceiverMonoBehaviour : MonoBehaviour
{
    /*
     * Requests that the laser receiver processes the impact of a laser.
     * If this returns true, the hit was processed; if it returns false, this laser receiver
     * is not interested in this hit and it will just pass through
     */
    public abstract bool LaserHit(LaserThread laserThread, RaycastHit hit);
}
