﻿/**
 * Copyright (c) 2013 Tobias Müller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using System;
using UnityEngine;
using System.Collections;

/*
 * A DetachedControllableEntityController applies the concepts mentioned in the description for
 * AbstractEntityController to a concrete ControllableEntity.
 */
[RequireComponent(typeof(ControlMarker))]
class DetachedControllableEntityController : AbstractEntityController
{
    [SerializeField] private ControllableEntity controllableEntityPrefab;
    [SerializeField] private bool preserveObject = true;

    private bool _show;

    protected override void Awake()
    {
        base.Awake();

        _show = false;

        if (preserveObject)
        {
            CreateControllableEntity();
        }
    }

    protected override void Update()
    {
        Show = markerObject.Required || (!controlMarker.NeedToExitThroughSide && markerObject.Detected);

        if (!Show)
            return;

        base.Update();
    }

    public bool Show
    {
        get { return _show; }
        set
        {
            if (_show == value)
                return;

            _show = value;

            if (preserveObject)
            {
                if (!_show)
                {
                    controllableEntity.InUse = false;
                    gameManager.PlayField.RemoveEntity(controllableEntity.GetComponent<Entity>());
                }
            }
            else
            {
                if (_show)
                {
                    CreateControllableEntity();
                }
                else
                {
                    DestroyControllableEntity();
                }
            }
        }
    }

    private void CreateControllableEntity()
    {
        controllableEntity = ((GameObject)Instantiate(controllableEntityPrefab.gameObject)).GetComponent<ControllableEntity>();
        controllableEntity.transform.position = new Vector3(0, 0, -100f);
        controllableEntity.transform.rotation = new Quaternion();
        controllableEntity.InUse = false;
    }

    private void DestroyControllableEntity()
    {
        controllableEntity.InUse = false;
        gameManager.PlayField.RemoveEntity(controllableEntity.GetComponent<Entity>());
        Destroy(controllableEntity.gameObject);
        controllableEntity = null;
    }
}
