﻿/**
 * Copyright (c) 2013 Tobias Müller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using System;
using System.Collections.Generic;
using UnityEngine;
using System.Collections;

/*
 * The Floor represented the floor of the playing field in a certain stage of the
 * development; it is not in use currently.
 */
class Floor : MonoBehaviour
{
    [SerializeField] private Collider floorCollider;

    private float _alpha = 1;
    private bool _shown = true;

    public Collider FloorCollider { get { return floorCollider; } }

    public float Alpha
    {
        get { return _alpha; }
        set
        {
            if (_alpha == value)
                return;

            _alpha = value;

            foreach (var childRenderer in GetComponentsInChildren<Renderer>())
            {
                var color = childRenderer.material.color;
                color.a = _alpha;
                childRenderer.material.color = color;
            }
        }
    }

    public bool Show
    {
        get { return _shown; }
        set
        {
            if (_shown == value)
                return;

            _shown = value;

            foreach (var childRenderer in GetComponentsInChildren<Renderer>())
            {
                childRenderer.enabled = _shown;
            }
        }
    }
}
