﻿/**
 * Copyright (c) 2013 Tobias Müller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using System;
using System.Collections.Generic;
using UnityEngine;
using System.Collections;

/*
 * A health orb floating around BaseEntity (in this case the wizards hat).
 */
public class HealthOrb : MonoBehaviour
{
    public BaseEntity BaseEntity { get; set; }

    public float BaseAngle { get; set; }

    public bool IsDead { get; private set; }

    private void Awake()
    {
        IsDead = false;
    }

    private void Update()
    {
        UpdatePosition();
    }

    public void UpdatePosition()
    {
        float time = Time.time;

        var offset = new Vector3();

        float angle = BaseAngle + time * BaseEntity.HealthOrbRotationSpeed;

        offset.x = Mathf.Cos(angle) * BaseEntity.HealthOrbDistance;
        offset.z = Mathf.Sin(angle) * BaseEntity.HealthOrbDistance;

        offset.y = Mathf.Cos(angle * BaseEntity.HealthOrbFloatAngleMultiplier) * BaseEntity.HealthOrbFloatDistance;

        transform.localPosition = offset;
    }

    // Fade the orb out
    public void Die()
    {
        IsDead = true;

        GetComponent<MeshRenderer>().enabled = false;

        if (particleSystem != null)
            particleSystem.loop = false;
    }
}
