﻿/**
 * Copyright (c) 2013 Tobias Müller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using System;
using System.Collections.Generic;
using UnityEngine;
using System.Collections;

/*
 * A lens takes a laser thread, filters it down to a color and makes it more powerful for
 * every color taken out.
 */
class LensEntity : LaserReceiverMonoBehaviour
{
    [SerializeField] private GameObject lensMesh;
    [SerializeField] private GameObject frameMesh;
    [SerializeField] private FlexibleColor targetColor;
    [SerializeField] private float rotationSpeedWhenNotActivated;
    [SerializeField] private float rotationSpeedWhenActivated;
    [SerializeField] private float addPowerPerFilteredColor = 0.25f;

    private bool usedByLaser;

    void Start()
    {
        var targetUnityColor = GameManager.FindInstance().GetColor(targetColor);
        targetUnityColor.a = 0.7f;

        var material = new Material(lensMesh.renderer.material);
        material.color = targetUnityColor;
        lensMesh.renderer.material = material;

        material = new Material(frameMesh.renderer.material);
        material.color = targetUnityColor;
        frameMesh.renderer.material = material;

        usedByLaser = false;
    }

    private void Update()
    {
        float rotationSpeed = usedByLaser ? rotationSpeedWhenActivated : rotationSpeedWhenNotActivated;

        if (rotationSpeed > 0)
        {
            frameMesh.transform.RotateAround(frameMesh.transform.position, frameMesh.transform.right, rotationSpeed * Time.deltaTime);
        }
    }

    private void OnMessageBeforeEmitting()
    {
        usedByLaser = false;
    }

    public override bool LaserHit(LaserThread laserThread, RaycastHit hit)
    {
        usedByLaser = true;

        var thisEntity = GetComponent<Entity>();

        var inDirection = laserThread.CurrentDirection;
        //var inNormal = hit.normal;

        var color = laserThread.Color;
        var power = laserThread.Power;

        AddPowerAndRemoveTestColorIfTestColorPresent(ref color, ref power, FlexibleColor.A);
        AddPowerAndRemoveTestColorIfTestColorPresent(ref color, ref power, FlexibleColor.B);
        AddPowerAndRemoveTestColorIfTestColorPresent(ref color, ref power, FlexibleColor.C);

        laserThread.AddPosition(hit.point, Vector3.zero);

        if (color > 0)
            laserThread.AddThread(hit.point, inDirection, power, color, thisEntity);

        return true;
    }

    private void AddPowerAndRemoveTestColorIfTestColorPresent(ref FlexibleColor color, ref float power, FlexibleColor testColor)
    {
        if (!targetColor.ContainsColor(testColor) && color.ContainsColor(testColor))
        {
            power += addPowerPerFilteredColor;
            color &= ~testColor;
        }
    }
}
