﻿/**
 * Copyright (c) 2013 Tobias Müller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using System;
using System.Collections.Generic;
using UnityEngine;

/*
 * A SingleLaserEmitterEntity emits a single laser thread from a certain point, in a certain color and
 * with a certain power.
 */
[RequireComponent(typeof(LaserEmitter))]
public class SingleLaserEmitterEntity : MonoBehaviour
{
    [SerializeField] private Transform laserStartPoint;
    [SerializeField] private FlexibleColor laserColor = FlexibleColor.A | FlexibleColor.B | FlexibleColor.C;
    [SerializeField] private float laserPower = 1;

    private LaserEmitter laserEmitter;

    void Awake()
    {
        laserEmitter = GetComponent<LaserEmitter>();
    }

    void Start()
    {
        var laserData = new LaserEmitter.LaserData();
        laserData.LocalPosition = transform.InverseTransformPoint(laserStartPoint.position);
        laserData.LocalDirection = transform.InverseTransformDirection(laserStartPoint.TransformDirection(0, 0, 1));
        laserData.Power = laserPower;
        laserData.Color = laserColor;

        laserEmitter.LaserDataList.Add(laserData);
    }
}
