/**
 * Copyright (c) 2013 Tobias Mller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using System;
using UnityEngine;
using System.Collections;

/*
 * This is the state the actual playing happens in.
 */
public class StatePlay : State
{
    private float elapsedGameTime;

    /**
     * The time the application spend in the actual game state.
     */
    public float ElapsedGameTime { get { return elapsedGameTime; } private set { elapsedGameTime = value; } }

    public override void Initialize()
    {
        base.Initialize();
    }

    public override void Activate()
    {
        gameManager.GamePaused = false;
        ARConsoleManager.FindInstance().ActivateButton(ARConsoleManager.ConsoleCommandType.RestartGame);

        var musicPlayer = MusicPlayer.FindInstance();
        musicPlayer.SwitchedToIngame();

        if (ElapsedGameTime == 0)
        {
            SoundManager.Instance.PlayGameStarts();
        }
    }

    public void ResetState()
    {
        ElapsedGameTime = 0;
    }

    public override void Deactivate()
    {
        gameManager.PlayField.GameStartsText.SetActive(false);
        gameManager.GamePaused = true;
    }

    public override void BeforeARUpdate()
    {
        if (gameManager.CheatCodesActive)
        {
            if (Input.GetKeyDown(KeyCode.F10))
            {
                gameManager.PlayField.CheatEnhanceLaser();
            }
            if (Input.GetKeyDown(KeyCode.F11))
            {
                gameManager.PlayField.CheatNoGameOver();
            }
        }
    }

    public override void AfterARUpdate()
    {
        // Increment elapsed game time, if StatePlay is getting updated.
        elapsedGameTime += Time.deltaTime;

        // Invoke an actual game update on the game manager.
        gameManager.GameUpdate(ElapsedGameTime);

        if (gameManager.DebugSkipConsole)
        {
            if (Input.GetKeyDown(KeyCode.Space))
            {
                arManager.UpdateOriginMarker = true;
            }
            else if (Input.GetKeyUp(KeyCode.Space))
            {
                arManager.UpdateOriginMarker = false;
            }
        }
    }

    private void SwitchToNextState()
    {
    }

    public override bool AcknowledgeNewRecognition(MarkerObject markerObject)
    {
        return true;
    }

    public override bool AcknowledgeUpdate(MarkerObject markerObject)
    {
        return true;
    }

    public override void DetectionStarted(MarkerObject markerObject)
    {
        UpdateControlMarkerStatus(markerObject);
    }

    public override void DetectionUpdated(MarkerObject markerObject)
    {
        UpdateControlMarkerStatus(markerObject);
    }

    public override void DetectionEnded(MarkerObject markerObject)
    {
        UpdateControlMarkerStatus(markerObject);
    }

    private void UpdateControlMarkerStatus(MarkerObject markerObject)
    {
        var controlMarker = markerObject.GetComponent<ControlMarker>();
        if (controlMarker == null)
            return;

        controlMarker.UpdateStatus();
    }
}
