/**
 * Copyright (c) 2013 Tobias Mller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using System;
using System.Collections.Generic;
using UnityEngine;
using System.Collections;

/*
 * This is a debugging state used to skip the console initialization. When a GameManager.DebugSkipConsole is
 * set, this will be the first State, and it will immediately switch to StatePlay once the origin marker is
 * found.
 */
public class StateSkipConsoleInitialization : State
{
    public override void Activate()
    {
    }

    public override void Deactivate()
    {
    }

    public override void BeforeARUpdate()
    {
    }

    public override void AfterARUpdate()
    {
        SwitchToNextState();
    }

    private void SwitchToNextState()
    {
        if (!arManager.OriginMarkerFound)
            return;

        arManager.UpdateOriginMarker = false;

        gameManager.SwitchToState(gameManager.PlayState);
    }

    public override bool AcknowledgeNewRecognition(MarkerObject markerObject)
    {
        return false;
    }

    public override bool AcknowledgeUpdate(MarkerObject markerObject)
    {
        return false;
    }

    public override void DetectionStarted(MarkerObject markerObject)
    {
    }

    public override void DetectionUpdated(MarkerObject markerObject)
    {
    }

    public override void DetectionEnded(MarkerObject markerObject)
    {
    }
}