/**
 * Copyright (c) 2013 Tobias Mller <Tobias_Mueller@gmx.com>, Tobias Wehrum <Tobias.Wehrum@dragonlab.de>
 * 
 * This file is part of Wizard Defense, A Cooperative Augmented Reality Game.
 * 
 * Distributed under the terms of the GNU GPL v3. For the full notice see the file LICENSE.
 */

using UnityEngine;
using System.Collections;

/*
 * The DebugManager is a simple tool to globally activate/deactivate certain debug outputs.
 */
public class DebugManager : MonoBehaviour
{
    [SerializeField] private bool showManagerDebugString;
    [SerializeField] private bool showMarkerObjectDebugData;

    private ARManager arManager;
    private GameManager gameManager;

    private bool previousShowMarkerObjectDebugData;

    void Awake()
    {
        arManager = ARManager.FindInstance();
        arManager.CallWhenInitialized(Initialize);
    }

    private void Initialize()
    {
        gameManager = GameManager.FindInstance();
        UpdateMarkerObjectDebugDataStatus();
    }

    void Update()
    {
        if (showMarkerObjectDebugData != previousShowMarkerObjectDebugData)
            UpdateMarkerObjectDebugDataStatus();
    }

    private void UpdateMarkerObjectDebugDataStatus()
    {
        previousShowMarkerObjectDebugData = showMarkerObjectDebugData;

        foreach (var markerObject in arManager.MarkerObjects)
        {
            markerObject.DebugShowData = showMarkerObjectDebugData;
        }
    }

    void OnGUI()
    {
        if (showManagerDebugString)
        {
            string text = arManager.GetDebugString() +
                          gameManager.GetDebugString();

            if (text.Length == 0)
                return;

            Vector2 size = GUI.skin.box.CalcSize(new GUIContent(text));
            Rect rect = new Rect(Screen.width / 2f - size.x / 2, Screen.height - size.y, size.x, size.y);

            GUI.skin.box.alignment = TextAnchor.MiddleCenter;
            GUI.Box(rect, text);
        }
    }
}
