﻿using System.Linq;
using UnityEngine;

/*
 * This class contains extension methods and helper methods for unity classes.
 */
public static class UnityHelper
{
    public static void CopyPositionAndRotatationFrom(this Transform transform, Transform source)
    {
        transform.position = source.position;
        transform.rotation = source.rotation;
    }

    public static void PlayAtCameraPosition(this AudioClip clip)
    {
        AudioSource.PlayClipAtPoint(clip, Camera.main.transform.position);
    }

    public static void PlayAtPosition(this AudioClip clip, GameObject gameObject)
    {
        AudioSource.PlayClipAtPoint(clip, gameObject.transform.position);
    }

    public static void PlayAtPosition(this AudioClip clip, Vector3 position)
    {
        AudioSource.PlayClipAtPoint(clip, position);
    }

    public static T FindFirstActiveInstance<T>() where T: MonoBehaviour
    {
        var instances = (T[]) UnityEngine.Object.FindSceneObjectsOfType(typeof (T));
        return instances.FirstOrDefault(instance => instance.gameObject.activeSelf);
    }
}
